#!/usr/bin/env python
# -*- coding:utf-8
import sys
import os
import requests
import json
from .. import config

IS_PY3 = sys.version_info.major
if IS_PY3 == 3:
    from urllib.parse import quote_plus
elif IS_PY3 == 2:
    from urllib import quote_plus


class Ai():
    def __init__(self):
        # 账号
        self._username = "w"
        # 密码
        self._password = "123456"

        # 主目录
        self._words_path = config._words_path
        self._speech_path = config._speech_path
        self._image_path = config._image_path

    #----文字识别
    def Ocr(self,image,e="low"):
        e=quote_plus(e)
        img_src= self._words_path+image
        files = {'file': (image, open( img_src, 'rb' ), 'image/bmp', {'Expires': '0'})}
        request_url = "http://api.pystargate.com:8000/ocr?e="+e+"&username=" + self._username + "&password="+self._password
        response = requests.post( request_url,files = files)
        result_str = response.text
        return result_str

    #----语音合成
    def SpeechSynthesis(self,say,save_file="SpeechSynthesis.mp3"):
        _say = say
        _save_file = save_file
        data = quote_plus( _say )
        request_url = "http://api.pystargate.com:8000/speech?say=" + str( data )+"&username=" + self._username + "&password="+self._password
        headers = {'content-type': 'application/x-www-form-urlencoded'}
        response = requests.get( request_url, headers=headers )
        result_str = response.content

        with open( self._speech_path + _save_file, 'wb+' ) as of:
            of.write( result_str )
            of.close()

        file = self._speech_path + _save_file
        os.system( file )
        return result_str

    #----图像识别
    def ImageSynthesis(self,image):
        img_src= self._image_path+image
        try:
            files = {'file': (image, open( img_src, 'rb' ), 'image/bmp', {'Expires': '0'})}
        except:
            return "未发现文件"
        request_url = "http://api.pystargate.com:8000/image?"+"username=" + self._username + "&password="+self._password
        response = requests.post( request_url,files = files)
        result_str = response.text
        keyword_arr=[]
        for i in range(0,len(json.loads( result_str )['result'])):
            keyword = json.loads( result_str )['result'][i]['keyword']
            keyword_arr.append(keyword)
            i = i + 1
        return keyword_arr



"""
软件名称:星门数据库(stargateDB)
描述：星门数据库是一款微型电脑数据库
官方首页：http://www.stargatedb.com/
文档教程：http://www.stargatedb.com/index.php/wendangjiaocheng.html
申请账号：http://www.stargatedb.com/index.php/page/user.html
作者：重庆羊排信息技术有限公司
发布日期：2021年4月1日
"""
from . import cloud,user


#!/usr/bin/ python
#coding:utf-8

"""
软件名称:星门数据库(stargateDB)
描述：星门数据库是一款微型电脑数据库
官方首页：http://www.stargatedb.com/
文档教程：http://www.stargatedb.com/index.php/wendangjiaocheng.html
申请账号：http://www.stargatedb.com/index.php/page/user.html
作者：重庆羊排信息技术有限公司
发布日期：2021年4月1日
"""
import hashlib
import requests
import time
import sys

IS_PY3 = sys.version_info.major
if IS_PY3 == 3:
    from urllib.parse import urlencode
    from urllib.parse import unquote
elif IS_PY3 == 2:
    from urllib import urlencode
    from urllib import unquote

#查看账号
def login(username,password):
    request_url = "http://api.stargatedb.com:8002/login?username=" + str(username)+"&password="+str(password)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url,headers=headers)
    result_str = response.text
    try:
        result=eval(result_str)
        return result
    except:
        return result_str

#-----示列代码,查看账号信息-----
# res=login("xxxxx","xxxxx")
# print("用户名："+str(res['username']))
# print("密码："+str(res['password']))
# print("所有空间："+str(res['allsize'])+"KB")
# print("已用空间："+str(res['usesize'])+"KB")
# print("空闲空间："+str(res['emptysize'])+"KB")


#!/usr/bin/env python
# -*- coding:utf-8

#----ai文字识别配置
'''words默认主目录设置'''
_words_path = "E:\\pool\\"

#----ai图像识别配置
'''image默认主目录设置'''
_image_path = "E:\\pool\\"

#----ai语音识别配置
'''speech默认主目录设置'''
_speech_path = "E:\\pool\\"

#----files文件操作配置
'''files默认主目录设置'''
_files_path = "E:\\pool\\"


import cv2
import time
from .. import config
from . import ai
class Camera():
    def __init__(self):
        self._ai=ai.Ai()

    #----摄像头抓拍识字
    def CameraCaptureOcr(self,image="CaptureOcr.png",e="low"):
        cap = cv2.VideoCapture( 0 )
        while (1):

            ret, frame = cap.read()
            cv2.imshow( "capture", frame )
            if cv2.waitKey( 1 ) & 0xFF == ord( 'q' ):
                cv2.imwrite( str( config._words_path ) + image, frame )
                break
        cap.release()
        cv2.destroyAllWindows()

        # res=pystargate.image.WordsCapture(1,1,111,111,"1.bmp")
        # print(res)
        res = self._ai.Ocr( image,e )
        return res

    #----摄像头抓拍识图
    def CameraCaptureImage(self,image="CaptureImage.png"):
        cap = cv2.VideoCapture( 0 )
        while (1):

            ret, frame = cap.read()
            cv2.imshow( "capture", frame )
            if cv2.waitKey( 1 ) & 0xFF == ord( 'q' ):
                cv2.imwrite( str( config._words_path ) + image, frame )
                break
        cap.release()
        cv2.destroyAllWindows()

        # res=pystargate.image.WordsCapture(1,1,111,111,"1.bmp")
        # print(res)
        res = self._ai.ImageSynthesis( image )
        return res

    #----摄像头抓拍
    def CameraCapture(self,image="Capture.png"):
        cap = cv2.VideoCapture( 0 )
        while (1):

            ret, frame = cap.read()
            cv2.imshow( "capture", frame )
            if cv2.waitKey( 1 ) & 0xFF == ord( 'q' ):
                cv2.imwrite( str( config._image_path ) + image, frame )
                break
        cap.release()
        cv2.destroyAllWindows()

    #----摄像头连续抓拍，t为抓拍间隔时间
    def CameraCaptureGo(self,image="CaptureGo.png",t=2):
        cap = cv2.VideoCapture( 0 )
        while (1):
            ret, frame = cap.read()
            cv2.imshow( "capture", frame )
            time.sleep(t)
            cv2.imwrite( str( config._image_path ) + image, frame )
            if cv2.waitKey( 1 ) & 0xFF == ord( 'q' ):
                break
        cap.release()
        cv2.destroyAllWindows()


#!/usr/bin/env python
# -*- coding:utf-8
import os, sys, shutil
import re
import cv2
import time
import pyscreenshot as ImageGrab
import pyautogui
from .. import config

# ----延时
def sleep(t=0):
    time.sleep(t)

# ----查找中文字符串是否存在
def FindCnStr(find_str, all_str):
    '''返回1代表查找成功，返回0代表查找失败'''
    if re.search( find_str, all_str, flags=re.I | re.M ) == None:
        return 0
    else:
        return 1

# ----查找字符串是否存在
def FindStr(find_str, all_str, f=0):
    '''f=1代表不区分大小写,返回1代表查找成功，返回0代表查找失败'''
    if f == 1:
        if re.search( find_str, all_str, flags=re.I | re.M ) == None:
            return 0
        else:
            return 1
    else:
        if re.search( find_str, all_str ) == None:
            return 0
        else:
            return 1

# ----图片批量压缩
'''in_dir代表图片原始目录，out_dir代表压缩后的存放目录'''
def ImgCompress(in_dir, out_dir,width,high,num=1):
    dir = config._image_path
    in_dir_path = dir + in_dir
    out_dir_path = dir + out_dir

    for i in range(0,num):
        image=cv2.imread(in_dir_path+ str(i) + ".jpg")

        res = cv2.resize(image, (width,high), interpolation=cv2.INTER_AREA)

        cv2.imwrite(out_dir_path+ str(i) + ".jpg",res)

#----遍历指定目录下的所有文件名
def FindFiles(dir):
    flist=[]
    for root,dirs,files in os.walk(config._files_path+dir):
        for file in files:
            flist.append(os.path.basename(os.path.join(root,file)))
    if flist==[]:
        return 0
    else:
        return flist

#----打开文件或应用程序
def OpenFiles(files_name):
    os.startfile(config._files_path+files_name)

#----复制文件
def CopyFiles(src,dst):
    try:
        if shutil.copy(config._files_path+src,config._files_path+dst):
            return 1
    except:
        return 0

#----批量复制文件
def BatchCopyFiles(src,dst,t=0):
    res=FindFiles( src )
    if res!=[]:
        for files_name in res:
            CopyFiles( src+"/"+files_name, dst )
            sleep( t )
        return 1
    else:
        return 0

#----移动文件
def MoveFiles(src,dst):
    try:
        if shutil.move(config._files_path+src,config._files_path+dst):
            return 1
    except:
        return 0

#----批量移动文件
def BatchMoveFiles(src,dst,t=0):
    res=FindFiles( src )
    if res!=[]:
        for files_name in res:
            MoveFiles( src+"/"+files_name, dst )
            sleep( t )
        return 1
    else:
        return 0

#----t秒后终止程序
def stop(t=0):
    time.sleep(t)
    sys.exit( 0 )

#----image截屏
def CommonImageCapture(x=None, y=None, x1=None, y1=None,image="ImageCapture.bmp" ,mod=1,t1=0,t2=0):
    time.sleep( t1 )
    if mod==1:
        img = ImageGrab.grab( bbox=(x, y, x1, y1) )
        img.save( config._image_path + image )
        return 1

    elif mod==2:
        print( "鼠标放在左上角" )
        x,y=pyautogui.position()
        time.sleep( t2 )
        print( "鼠标放在右下角" )
        time.sleep( t2 )
        x1,y1 = pyautogui.position()
        img = ImageGrab.grab( bbox=(x, y, x1, y1) )
        img.save( config._image_path + image )
        return 1

#----words截屏
def CommonWordsCapture(x=None, y=None, x1=None, y1=None,image="WordsCapture.bmp",mod=1,t1=0,t2=0):
    time.sleep( t1 )
    if mod==1:
        img = ImageGrab.grab( bbox=(x, y, x1, y1) )
        img.save( config._words_path + image)
        return 1

    elif mod==2:
        print( "鼠标放在左上角" )
        x,y=pyautogui.position()
        time.sleep( t2 )
        print( "鼠标放在右下角" )
        time.sleep( t2 )
        x1,y1 = pyautogui.position()
        img = ImageGrab.grab( bbox=(x, y, x1, y1) )
        img.save( config._words_path + image )
        return 1


#!/usr/bin/env python
# -*- coding:utf-8
from .libs import tkinter as tkinker
_tkinker=tkinker.Tkinter()

def Button(_div,text,color1=None,color2=None,command=None,width=None,height=None,place=1):
    _tkinker.TkinterButton(_div,text,color1,color2,command,width,height,place)

def Label( _div,text, color=None, width=None, height=None,place=1):
    _tkinker.TkinterLabel( _div,text, color, width, height,place)

def Div():
    return _tkinker.TkinterDiv()

def ShowDiv(div):
    _tkinker.TkinterShowDiv(div)


#!/usr/bin/env python
# -*- coding:utf-8
from .libs import autogui,common
_autogui=autogui.Autogui()
_common=common

def GetMousePositon(t=0):
    return _autogui.AutoguiGetMousePositon(t)

def MoveTo(x,y,duration=0):
    _autogui.AutoguiMoveTo(x,y,duration)

def MoveRel(left_right=0, up_down=0, duration=0):
    _autogui.AutoguiMoveRel(left_right, up_down, duration)

def Click(x=0,y=0,click_number=1,interval=0.0,button='left'):
    _autogui.AutoguiClick(x,y,click_number,interval,button)

def Scroll(number,x=None,y=None):
    _autogui.AutoguiScroll(number,x,y)


#!/usr/bin/env python
# -*- coding:utf-8

"""
软件名称:星门数据库(stargateDB)
描述：星门数据库是一款微型电脑云数据库
官方首页：http://www.stargatedb.com/
文档教程：http://www.stargatedb.com/index.php/wendangjiaocheng.html
申请账号：http://www.stargatedb.com/index.php/page/user.html
作者：重庆羊排信息技术有限公司
发布日期：2021年4月1日
"""

# -----示列代码-----

# import stargatedb.cloud as cloud

# 添加字符数据
# res=Add("wumeng","xxxxx","xxxxx","无梦","new",30)
# print(res)

# 修改字符数据
# res=Change("xxxxx","xxxxx","new",10)
# print(res)

# 删除字符数据
# res=Delete("xxxxx","xxxxx")
# print(res)

# 查找字符数据
# res=AllFind("xxxxx","xxxxx","new")
# for i in res:
#     print(res[i]['value'])

# 添加音频数据
# res=AddAudio("xxxxx","xxxxx","1.mp3","new","./new/")
# print(res)

# 查找音频数据
# res=FindAudio("xxxxx","xxxxx","1.mp3","new","./test/")
# print(res)

# 删除音频数据
# res=DeleteAudio("xxxxx","xxxxx","1.mp3","new")
# print(res)




#!/usr/bin/env python
# -*- coding:utf-8
import time
import pyautogui

class Autogui():

    #----获取鼠标位置
    def AutoguiGetMousePositon(self,t=0):
        time.sleep( t )
        x,y = pyautogui.position()
        return x,y

    #----屏幕的宽和高
    def AutoguiWindowSize(self):
        width, height = pyautogui.size() # 屏幕的宽度和高度
        return width,height

    #----鼠标移动
    def AutoguiMoveTo(self,x,y,duration=0):
        pyautogui.moveTo( x, y, duration )

    #----鼠标位移
    def AutoguiMoveRel(self,left_right=0, up_down=0, duration=0):
        pyautogui.moveRel( left_right, up_down, duration )

    #----鼠标移动点击
    def AutoguiClick(self,x=0,y=0,click_number=1,interval=0.0,button='left'):
        pyautogui.click(x, y, click_number,interval, button)

    #----鼠标滚动
    def AutoguiScroll(self,number,x=None,y=None):
        pyautogui.scroll(number, x, y)

    #----输入字符串和数字
    def AutoguiSayString(self,char,interval=0.0):
        pyautogui.typewrite( char,interval )

    # ----热键组合
    def AutoguiHotKey(self,one,two):
        pyautogui.hotkey( one, two )


#!/usr/bin/env python
# -*- coding:utf-8
# import sys
# from . import data
# try:
#     data.Client()
# except:
#     print( "redis未连接，请先连接redis" )
#     sys.exit(0)

#初始化控制器
from . import mouse,image,keyboard,words,input,config,window,time,files,view,machineVision,machineSpeech,user

# #初始化libs库
# from stargate.libs import autogui as autogui
# from stargate.libs import extend as extend
# from stargate.libs import baidu as baidu
# from stargate.libs import common as common
# from stargate.libs import redis as redis
# from stargate.libs import opencv as opencv
#
# _autogui=autogui.Autogui()
# _extend=extend.Extend()
# _baidu=baidu.Baidu()
# _redis=redis.Redis()
# _opencv=opencv.Opencv()
# _common=common



#!/usr/bin/env python
# -*- coding:utf-8
from .libs import common,extend
_common=common
_extend=extend.Extend()

def BatchFindFiles(dir):
    return _common.FindFiles(dir)

def OpenFiles(files_name):
    _common.OpenFiles(files_name)

def BatchFindOpenFiles(files_dir):
    _extend.FindOpenFiles(files_dir)

def CopyFiles(src,dst):
    return _common.CopyFiles(src,dst)

def BatchCopyFiles(src,dst,t=0):
    return _common.BatchCopyFiles(src,dst,t)

def MoveFiles(src,dst):
    return _common.MoveFiles(src,dst)

def BatchMoveFiles(src,dst,t=0):
    return _common.BatchMoveFiles(src,dst,t)


import setuptools
setuptools.setup(
    name="pystargate", # Replace with your own username
    version="1.0.3",
    author="yangpai",
    author_email="wumeng@mail.yangpai.co",
    description="pyStargate engine is an open source (IPA) intelligent process automation development framework",
    long_description="pyStargate engine is an open source (IPA) intelligent process automation development framework",
    long_description_content_type="text/markdown",
    url="http://www.pystargate.com",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 2",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=2.7'
)



#!/usr/bin/ python
#coding:utf-8

import hashlib
import requests
import time
import sys

IS_PY3 = sys.version_info.major
if IS_PY3 == 3:
    from urllib.parse import urlencode
    from urllib.parse import unquote
elif IS_PY3 == 2:
    from urllib import urlencode
    from urllib import unquote

# 查看账号
def login(username,password):
    request_url = "http://api.pystargate.com:8000/login?username=" + str(username)+"&password="+str(password)
    headers = {'content-type': 'application/x-www-form-urlencoded'}
    response = requests.post( request_url,headers=headers)
    result_str = response.text
    try:
        result=eval(result_str)
        return result
    except:
        return result_str

# #-----示列代码,查看账号信息-----
# res=login("w","123456")
# print("用户名："+str(res['username']))
# print("密码："+str(res['password']))
# print("级别："+str(res['level'])+"级")



from .libs import camera
_camera=camera.Camera()

def CaptureOcr(image="CaptureOcr.png",e="low"):
    return _camera.CameraCaptureOcr(image,e)

def CaptureImage(image="CaptureImage.png"):
    return _camera.CameraCaptureImage(image)

def Capture(image="Capture.png"):
    return _camera.CameraCapture(image)

def CaptureGo(image="CaptureGo.png",t=2):
    return _camera.CameraCaptureGo(image,t)